@@ -3,8 +3,9 @@ Main interface for ram service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.ram import (
+    from mypy_boto3_ram import (
         Client,
         GetResourcePoliciesPaginator,
         GetResourceShareAssociationsPaginator,
@@ -13,7 +14,7 @@ Usage::
         ListPrincipalsPaginator,
         ListResourcesPaginator,
         RAMClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -26,8 +27,9 @@ Usage::
     get_resource_shares_paginator: GetResourceSharesPaginator = client.get_paginator("get_resource_shares")
     list_principals_paginator: ListPrincipalsPaginator = client.get_paginator("list_principals")
     list_resources_paginator: ListResourcesPaginator = client.get_paginator("list_resources")
+    ```
 """
-from mypy_boto3_ram.client import RAMClient as Client, RAMClient
+from mypy_boto3_ram.client import RAMClient, RAMClient as Client
 from mypy_boto3_ram.paginator import (
     GetResourcePoliciesPaginator,
     GetResourceShareAssociationsPaginator,
