@@ -3,8 +3,11 @@ Main interface for ram service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.ram import (
+
+    from mypy_boto3_ram import RAMClient
+    from mypy_boto3_ram import (
         GetResourcePoliciesPaginator,
         GetResourceShareAssociationsPaginator,
         GetResourceShareInvitationsPaginator,
@@ -21,6 +24,7 @@ Usage::
     get_resource_shares_paginator: GetResourceSharesPaginator = client.get_paginator("get_resource_shares")
     list_principals_paginator: ListPrincipalsPaginator = client.get_paginator("list_principals")
     list_resources_paginator: ListResourcesPaginator = client.get_paginator("list_resources")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
@@ -55,7 +59,7 @@ __all__ = (
 
 class GetResourcePoliciesPaginator(Boto3Paginator):
     """
-    [Paginator.GetResourcePolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
+    [Paginator.GetResourcePolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
     """
 
     def paginate(
@@ -65,13 +69,13 @@ class GetResourcePoliciesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetResourcePoliciesResponseTypeDef]:
         """
-        [GetResourcePolicies.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/ram.html#RAM.Paginator.GetResourcePolicies.paginate)
+        [GetResourcePolicies.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourcePolicies.paginate)
         """
 
 
 class GetResourceShareAssociationsPaginator(Boto3Paginator):
     """
-    [Paginator.GetResourceShareAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
+    [Paginator.GetResourceShareAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
     """
 
     def paginate(
@@ -86,13 +90,13 @@ class GetResourceShareAssociationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetResourceShareAssociationsResponseTypeDef]:
         """
-        [GetResourceShareAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations.paginate)
+        [GetResourceShareAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations.paginate)
         """
 
 
 class GetResourceShareInvitationsPaginator(Boto3Paginator):
     """
-    [Paginator.GetResourceShareInvitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
+    [Paginator.GetResourceShareInvitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
     """
 
     def paginate(
@@ -102,13 +106,13 @@ class GetResourceShareInvitationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetResourceShareInvitationsResponseTypeDef]:
         """
-        [GetResourceShareInvitations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations.paginate)
+        [GetResourceShareInvitations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations.paginate)
         """
 
 
 class GetResourceSharesPaginator(Boto3Paginator):
     """
-    [Paginator.GetResourceShares documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/ram.html#RAM.Paginator.GetResourceShares)
+    [Paginator.GetResourceShares documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourceShares)
     """
 
     def paginate(
@@ -121,13 +125,13 @@ class GetResourceSharesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetResourceSharesResponseTypeDef]:
         """
-        [GetResourceShares.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/ram.html#RAM.Paginator.GetResourceShares.paginate)
+        [GetResourceShares.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourceShares.paginate)
         """
 
 
 class ListPrincipalsPaginator(Boto3Paginator):
     """
-    [Paginator.ListPrincipals documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/ram.html#RAM.Paginator.ListPrincipals)
+    [Paginator.ListPrincipals documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.ListPrincipals)
     """
 
     def paginate(
@@ -140,13 +144,13 @@ class ListPrincipalsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListPrincipalsResponseTypeDef]:
         """
-        [ListPrincipals.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/ram.html#RAM.Paginator.ListPrincipals.paginate)
+        [ListPrincipals.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.ListPrincipals.paginate)
         """
 
 
 class ListResourcesPaginator(Boto3Paginator):
     """
-    [Paginator.ListResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/ram.html#RAM.Paginator.ListResources)
+    [Paginator.ListResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.ListResources)
     """
 
     def paginate(
@@ -159,5 +163,5 @@ class ListResourcesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListResourcesResponseTypeDef]:
         """
-        [ListResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/ram.html#RAM.Paginator.ListResources.paginate)
+        [ListResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.ListResources.paginate)
         """
