@@ -3,9 +3,11 @@ Main interface for ram service type definitions.
 
 Usage::
 
-    from mypy_boto3.ram.type_defs import ResourceShareAssociationTypeDef
+    ```python
+    from mypy_boto3_ram.type_defs import PrincipalTypeDef
 
-    data: ResourceShareAssociationTypeDef = {...}
+    data: PrincipalTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
@@ -22,32 +24,32 @@ else:
 
 
 __all__ = (
+    "PrincipalTypeDef",
     "ResourceShareAssociationTypeDef",
     "ResourceShareInvitationTypeDef",
+    "ResourceSharePermissionDetailTypeDef",
+    "ResourceSharePermissionSummaryTypeDef",
+    "ResourceShareTypeDef",
+    "ResourceTypeDef",
+    "ServiceNameAndResourceTypeTypeDef",
+    "TagTypeDef",
     "AcceptResourceShareInvitationResponseTypeDef",
     "AssociateResourceSharePermissionResponseTypeDef",
     "AssociateResourceShareResponseTypeDef",
-    "TagTypeDef",
-    "ResourceShareTypeDef",
     "CreateResourceShareResponseTypeDef",
     "DeleteResourceShareResponseTypeDef",
     "DisassociateResourceSharePermissionResponseTypeDef",
     "DisassociateResourceShareResponseTypeDef",
     "EnableSharingWithAwsOrganizationResponseTypeDef",
-    "ResourceSharePermissionDetailTypeDef",
     "GetPermissionResponseTypeDef",
     "GetResourcePoliciesResponseTypeDef",
     "GetResourceShareAssociationsResponseTypeDef",
     "GetResourceShareInvitationsResponseTypeDef",
     "GetResourceSharesResponseTypeDef",
-    "ResourceTypeDef",
     "ListPendingInvitationResourcesResponseTypeDef",
-    "ResourceSharePermissionSummaryTypeDef",
     "ListPermissionsResponseTypeDef",
-    "PrincipalTypeDef",
     "ListPrincipalsResponseTypeDef",
     "ListResourceSharePermissionsResponseTypeDef",
-    "ServiceNameAndResourceTypeTypeDef",
     "ListResourceTypesResponseTypeDef",
     "ListResourcesResponseTypeDef",
     "PaginatorConfigTypeDef",
@@ -57,6 +59,18 @@ __all__ = (
     "UpdateResourceShareResponseTypeDef",
 )
 
+PrincipalTypeDef = TypedDict(
+    "PrincipalTypeDef",
+    {
+        "id": str,
+        "resourceShareArn": str,
+        "creationTime": datetime,
+        "lastUpdatedTime": datetime,
+        "external": bool,
+    },
+    total=False,
+)
+
 ResourceShareAssociationTypeDef = TypedDict(
     "ResourceShareAssociationTypeDef",
     {
@@ -83,74 +97,11 @@ ResourceShareInvitationTypeDef = TypedDict(
         "receiverAccountId": str,
         "invitationTimestamp": datetime,
         "status": Literal["PENDING", "ACCEPTED", "REJECTED", "EXPIRED"],
-        "resourceShareAssociations": List[ResourceShareAssociationTypeDef],
+        "resourceShareAssociations": List["ResourceShareAssociationTypeDef"],
     },
     total=False,
 )
 
-AcceptResourceShareInvitationResponseTypeDef = TypedDict(
-    "AcceptResourceShareInvitationResponseTypeDef",
-    {"resourceShareInvitation": ResourceShareInvitationTypeDef, "clientToken": str},
-    total=False,
-)
-
-AssociateResourceSharePermissionResponseTypeDef = TypedDict(
-    "AssociateResourceSharePermissionResponseTypeDef",
-    {"returnValue": bool, "clientToken": str},
-    total=False,
-)
-
-AssociateResourceShareResponseTypeDef = TypedDict(
-    "AssociateResourceShareResponseTypeDef",
-    {"resourceShareAssociations": List[ResourceShareAssociationTypeDef], "clientToken": str},
-    total=False,
-)
-
-TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str}, total=False)
-
-ResourceShareTypeDef = TypedDict(
-    "ResourceShareTypeDef",
-    {
-        "resourceShareArn": str,
-        "name": str,
-        "owningAccountId": str,
-        "allowExternalPrincipals": bool,
-        "status": Literal["PENDING", "ACTIVE", "FAILED", "DELETING", "DELETED"],
-        "statusMessage": str,
-        "tags": List[TagTypeDef],
-        "creationTime": datetime,
-        "lastUpdatedTime": datetime,
-        "featureSet": Literal["CREATED_FROM_POLICY", "PROMOTING_TO_STANDARD", "STANDARD"],
-    },
-    total=False,
-)
-
-CreateResourceShareResponseTypeDef = TypedDict(
-    "CreateResourceShareResponseTypeDef",
-    {"resourceShare": ResourceShareTypeDef, "clientToken": str},
-    total=False,
-)
-
-DeleteResourceShareResponseTypeDef = TypedDict(
-    "DeleteResourceShareResponseTypeDef", {"returnValue": bool, "clientToken": str}, total=False
-)
-
-DisassociateResourceSharePermissionResponseTypeDef = TypedDict(
-    "DisassociateResourceSharePermissionResponseTypeDef",
-    {"returnValue": bool, "clientToken": str},
-    total=False,
-)
-
-DisassociateResourceShareResponseTypeDef = TypedDict(
-    "DisassociateResourceShareResponseTypeDef",
-    {"resourceShareAssociations": List[ResourceShareAssociationTypeDef], "clientToken": str},
-    total=False,
-)
-
-EnableSharingWithAwsOrganizationResponseTypeDef = TypedDict(
-    "EnableSharingWithAwsOrganizationResponseTypeDef", {"returnValue": bool}, total=False
-)
-
 ResourceSharePermissionDetailTypeDef = TypedDict(
     "ResourceSharePermissionDetailTypeDef",
     {
@@ -166,31 +117,35 @@ ResourceSharePermissionDetailTypeDef = TypedDict(
     total=False,
 )
 
-GetPermissionResponseTypeDef = TypedDict(
-    "GetPermissionResponseTypeDef",
-    {"permission": ResourceSharePermissionDetailTypeDef},
+ResourceSharePermissionSummaryTypeDef = TypedDict(
+    "ResourceSharePermissionSummaryTypeDef",
+    {
+        "arn": str,
+        "version": str,
+        "defaultVersion": bool,
+        "name": str,
+        "resourceType": str,
+        "status": str,
+        "creationTime": datetime,
+        "lastUpdatedTime": datetime,
+    },
     total=False,
 )
 
-GetResourcePoliciesResponseTypeDef = TypedDict(
-    "GetResourcePoliciesResponseTypeDef", {"policies": List[str], "nextToken": str}, total=False
-)
-
-GetResourceShareAssociationsResponseTypeDef = TypedDict(
-    "GetResourceShareAssociationsResponseTypeDef",
-    {"resourceShareAssociations": List[ResourceShareAssociationTypeDef], "nextToken": str},
-    total=False,
-)
-
-GetResourceShareInvitationsResponseTypeDef = TypedDict(
-    "GetResourceShareInvitationsResponseTypeDef",
-    {"resourceShareInvitations": List[ResourceShareInvitationTypeDef], "nextToken": str},
-    total=False,
-)
-
-GetResourceSharesResponseTypeDef = TypedDict(
-    "GetResourceSharesResponseTypeDef",
-    {"resourceShares": List[ResourceShareTypeDef], "nextToken": str},
+ResourceShareTypeDef = TypedDict(
+    "ResourceShareTypeDef",
+    {
+        "resourceShareArn": str,
+        "name": str,
+        "owningAccountId": str,
+        "allowExternalPrincipals": bool,
+        "status": Literal["PENDING", "ACTIVE", "FAILED", "DELETING", "DELETED"],
+        "statusMessage": str,
+        "tags": List["TagTypeDef"],
+        "creationTime": datetime,
+        "lastUpdatedTime": datetime,
+        "featureSet": Literal["CREATED_FROM_POLICY", "PROMOTING_TO_STANDARD", "STANDARD"],
+    },
     total=False,
 )
 
@@ -211,70 +166,117 @@ ResourceTypeDef = TypedDict(
     total=False,
 )
 
-ListPendingInvitationResourcesResponseTypeDef = TypedDict(
-    "ListPendingInvitationResourcesResponseTypeDef",
-    {"resources": List[ResourceTypeDef], "nextToken": str},
+ServiceNameAndResourceTypeTypeDef = TypedDict(
+    "ServiceNameAndResourceTypeTypeDef", {"resourceType": str, "serviceName": str}, total=False
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str}, total=False)
+
+AcceptResourceShareInvitationResponseTypeDef = TypedDict(
+    "AcceptResourceShareInvitationResponseTypeDef",
+    {"resourceShareInvitation": "ResourceShareInvitationTypeDef", "clientToken": str},
     total=False,
 )
 
-ResourceSharePermissionSummaryTypeDef = TypedDict(
-    "ResourceSharePermissionSummaryTypeDef",
-    {
-        "arn": str,
-        "version": str,
-        "defaultVersion": bool,
-        "name": str,
-        "resourceType": str,
-        "status": str,
-        "creationTime": datetime,
-        "lastUpdatedTime": datetime,
-    },
+AssociateResourceSharePermissionResponseTypeDef = TypedDict(
+    "AssociateResourceSharePermissionResponseTypeDef",
+    {"returnValue": bool, "clientToken": str},
+    total=False,
+)
+
+AssociateResourceShareResponseTypeDef = TypedDict(
+    "AssociateResourceShareResponseTypeDef",
+    {"resourceShareAssociations": List["ResourceShareAssociationTypeDef"], "clientToken": str},
+    total=False,
+)
+
+CreateResourceShareResponseTypeDef = TypedDict(
+    "CreateResourceShareResponseTypeDef",
+    {"resourceShare": "ResourceShareTypeDef", "clientToken": str},
+    total=False,
+)
+
+DeleteResourceShareResponseTypeDef = TypedDict(
+    "DeleteResourceShareResponseTypeDef", {"returnValue": bool, "clientToken": str}, total=False
+)
+
+DisassociateResourceSharePermissionResponseTypeDef = TypedDict(
+    "DisassociateResourceSharePermissionResponseTypeDef",
+    {"returnValue": bool, "clientToken": str},
+    total=False,
+)
+
+DisassociateResourceShareResponseTypeDef = TypedDict(
+    "DisassociateResourceShareResponseTypeDef",
+    {"resourceShareAssociations": List["ResourceShareAssociationTypeDef"], "clientToken": str},
+    total=False,
+)
+
+EnableSharingWithAwsOrganizationResponseTypeDef = TypedDict(
+    "EnableSharingWithAwsOrganizationResponseTypeDef", {"returnValue": bool}, total=False
+)
+
+GetPermissionResponseTypeDef = TypedDict(
+    "GetPermissionResponseTypeDef",
+    {"permission": "ResourceSharePermissionDetailTypeDef"},
+    total=False,
+)
+
+GetResourcePoliciesResponseTypeDef = TypedDict(
+    "GetResourcePoliciesResponseTypeDef", {"policies": List[str], "nextToken": str}, total=False
+)
+
+GetResourceShareAssociationsResponseTypeDef = TypedDict(
+    "GetResourceShareAssociationsResponseTypeDef",
+    {"resourceShareAssociations": List["ResourceShareAssociationTypeDef"], "nextToken": str},
+    total=False,
+)
+
+GetResourceShareInvitationsResponseTypeDef = TypedDict(
+    "GetResourceShareInvitationsResponseTypeDef",
+    {"resourceShareInvitations": List["ResourceShareInvitationTypeDef"], "nextToken": str},
+    total=False,
+)
+
+GetResourceSharesResponseTypeDef = TypedDict(
+    "GetResourceSharesResponseTypeDef",
+    {"resourceShares": List["ResourceShareTypeDef"], "nextToken": str},
+    total=False,
+)
+
+ListPendingInvitationResourcesResponseTypeDef = TypedDict(
+    "ListPendingInvitationResourcesResponseTypeDef",
+    {"resources": List["ResourceTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListPermissionsResponseTypeDef = TypedDict(
     "ListPermissionsResponseTypeDef",
-    {"permissions": List[ResourceSharePermissionSummaryTypeDef], "nextToken": str},
-    total=False,
-)
-
-PrincipalTypeDef = TypedDict(
-    "PrincipalTypeDef",
-    {
-        "id": str,
-        "resourceShareArn": str,
-        "creationTime": datetime,
-        "lastUpdatedTime": datetime,
-        "external": bool,
-    },
+    {"permissions": List["ResourceSharePermissionSummaryTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListPrincipalsResponseTypeDef = TypedDict(
     "ListPrincipalsResponseTypeDef",
-    {"principals": List[PrincipalTypeDef], "nextToken": str},
+    {"principals": List["PrincipalTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListResourceSharePermissionsResponseTypeDef = TypedDict(
     "ListResourceSharePermissionsResponseTypeDef",
-    {"permissions": List[ResourceSharePermissionSummaryTypeDef], "nextToken": str},
+    {"permissions": List["ResourceSharePermissionSummaryTypeDef"], "nextToken": str},
     total=False,
 )
 
-ServiceNameAndResourceTypeTypeDef = TypedDict(
-    "ServiceNameAndResourceTypeTypeDef", {"resourceType": str, "serviceName": str}, total=False
-)
-
 ListResourceTypesResponseTypeDef = TypedDict(
     "ListResourceTypesResponseTypeDef",
-    {"resourceTypes": List[ServiceNameAndResourceTypeTypeDef], "nextToken": str},
+    {"resourceTypes": List["ServiceNameAndResourceTypeTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListResourcesResponseTypeDef = TypedDict(
     "ListResourcesResponseTypeDef",
-    {"resources": List[ResourceTypeDef], "nextToken": str},
+    {"resources": List["ResourceTypeDef"], "nextToken": str},
     total=False,
 )
 
@@ -288,7 +290,7 @@ PromoteResourceShareCreatedFromPolicyResponseTypeDef = TypedDict(
 
 RejectResourceShareInvitationResponseTypeDef = TypedDict(
     "RejectResourceShareInvitationResponseTypeDef",
-    {"resourceShareInvitation": ResourceShareInvitationTypeDef, "clientToken": str},
+    {"resourceShareInvitation": "ResourceShareInvitationTypeDef", "clientToken": str},
     total=False,
 )
 
@@ -298,6 +300,6 @@ TagFilterTypeDef = TypedDict(
 
 UpdateResourceShareResponseTypeDef = TypedDict(
     "UpdateResourceShareResponseTypeDef",
-    {"resourceShare": ResourceShareTypeDef, "clientToken": str},
+    {"resourceShare": "ResourceShareTypeDef", "clientToken": str},
     total=False,
 )
